@@ -25,13 +25,11 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gdk/gdkkeysyms-compat.h>
-#endif
 #include <gio/gio.h>
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
 #include <glib/gi18n.h>
+#include <libmate-desktop/mate-aboutdialog.h>
 #include <stdlib.h>
 #include <string.h>
 
@@ -42,6 +40,11 @@
 #include "cpufreq-monitor-factory.h"
 #include "cpufreq-utils.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 struct _CPUFreqApplet {
         MatePanelApplet       base;
 
@@ -98,11 +101,7 @@ static void     cpufreq_applet_update            (CPUFreqApplet      *applet,
                                                   CPUFreqMonitor     *monitor);
 static void     cpufreq_applet_refresh           (CPUFreqApplet      *applet);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void     cpufreq_applet_dispose           (GObject            *widget);
-#else
-static void     cpufreq_applet_destroy           (GtkObject          *widget);
-#endif
 static gboolean cpufreq_applet_button_press      (GtkWidget          *widget,
                                                   GdkEventButton     *event);
 static gboolean cpufreq_applet_key_press         (GtkWidget          *widget,
@@ -227,18 +226,10 @@ static void
 cpufreq_applet_class_init (CPUFreqAppletClass *klass)
 {
         MatePanelAppletClass *applet_class = MATE_PANEL_APPLET_CLASS (klass);
-#if GTK_CHECK_VERSION (3, 0, 0)
         GObjectClass     *gobject_class = G_OBJECT_CLASS (klass);
-#else
-        GtkObjectClass   *gtkobject_class = GTK_OBJECT_CLASS (klass);
-#endif
         GtkWidgetClass   *widget_class = GTK_WIDGET_CLASS (klass);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         gobject_class->dispose = cpufreq_applet_dispose;
-#else
-        gtkobject_class->destroy = cpufreq_applet_destroy;
-#endif
 
         widget_class->size_allocate = cpufreq_applet_size_allocate;
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -253,11 +244,7 @@ cpufreq_applet_class_init (CPUFreqAppletClass *klass)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 cpufreq_applet_dispose (GObject *widget)
-#else
-cpufreq_applet_destroy (GtkObject *widget)
-#endif
 {
         CPUFreqApplet *applet;
         gint           i;
@@ -286,11 +273,7 @@ cpufreq_applet_destroy (GtkObject *widget)
                 applet->popup = NULL;
         }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
         G_OBJECT_CLASS (cpufreq_applet_parent_class)->dispose (widget);
-#else
-        GTK_OBJECT_CLASS (cpufreq_applet_parent_class)->destroy (widget);
-#endif
 }
 
 static void
@@ -467,7 +450,7 @@ cpufreq_applet_size_request (GtkWidget *widget, GtkRequisition *requisition)
 		gint icon_width;
 
 		gtk_widget_get_preferred_width (applet->icon, &icon_width, NULL);
-		width = GTK_IS_HBOX (applet->box) ?
+		width = gtk_orientable_get_orientation (GTK_ORIENTABLE (applet->box)) == GTK_ORIENTATION_HORIZONTAL ?
 			labels_width + icon_width + 2 :
 			MAX (labels_width, icon_width + 2);
 #else
@@ -596,12 +579,12 @@ cpufreq_applet_key_press (GtkWidget *widget, GdkEventKey *event)
         applet = CPUFREQ_APPLET (widget);
 
         switch (event->keyval) {
-        case GDK_KP_Enter:
-        case GDK_ISO_Enter:
-        case GDK_3270_Enter:
-        case GDK_Return:
-        case GDK_space:
-        case GDK_KP_Space:
+        case GDK_KEY_KP_Enter:
+        case GDK_KEY_ISO_Enter:
+        case GDK_KEY_3270_Enter:
+        case GDK_KEY_Return:
+        case GDK_KEY_space:
+        case GDK_KEY_KP_Space:
                 cpufreq_applet_menu_popup (applet, event->time);
 
                 return TRUE;
@@ -686,7 +669,7 @@ cpufreq_applet_about_cb (GtkAction     *action,
                 NULL
         };
 
-        gtk_show_about_dialog (NULL,
+        mate_show_about_dialog (NULL,
                                "version",       VERSION,
                                "copyright",     "\xC2\xA9 2004 Carlos Garcia Campos",
                                "comments",      _("This utility shows the current CPU "
