@@ -31,7 +31,6 @@
 #include <gdk/gdkkeysyms.h>
 #if GTK_CHECK_VERSION (3, 0, 0)
 #include <gio/gdesktopappinfo.h>
-#include <gdk/gdkkeysyms-compat.h>
 #endif
 
 #include <string.h>
@@ -53,11 +52,7 @@ static void     drive_button_set_mount    (DriveButton    *self,
 static void     drive_button_reset_popup  (DriveButton    *self);
 static void     drive_button_ensure_popup (DriveButton    *self);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 static void     drive_button_dispose      (GObject        *object);
-#else
-static void     drive_button_destroy      (GtkObject      *object);
-#endif
 #if 0
 static void     drive_button_unrealize    (GtkWidget      *widget);
 #endif /* 0 */
@@ -71,14 +66,27 @@ static void drive_button_theme_change     (GtkIconTheme   *icon_theme,
 static void
 drive_button_class_init (DriveButtonClass *class)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
     G_OBJECT_CLASS(class)->dispose = drive_button_dispose;
-#else
-    GTK_OBJECT_CLASS(class)->destroy = drive_button_destroy;
-#endif
     GTK_WIDGET_CLASS(class)->button_press_event = drive_button_button_press;
     GTK_WIDGET_CLASS(class)->key_press_event = drive_button_key_press;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    GtkCssProvider *provider;
+
+    provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (provider,
+                                     "DriveButton {\n"
+                                     " border-width: 0px;\n"
+                                     " -GtkWidget-focus-line-width: 0px;\n"
+                                     " -GtkWidget-focus-padding: 0px;\n"
+                                     "}",
+                                     -1, NULL);
+    gtk_style_context_add_provider_for_screen (gdk_screen_get_default(),
+                                    GTK_STYLE_PROVIDER (provider),
+                                    GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    g_object_unref (provider);
+
+#else
     gtk_rc_parse_string ("\n"
 			 "   style \"drive-button-style\"\n"
 			 "   {\n"
@@ -92,6 +100,7 @@ drive_button_class_init (DriveButtonClass *class)
 			 "\n"
 			 "    class \"DriveButton\" style \"drive-button-style\"\n"
 			 "\n");
+#endif
 }
 
 static void
@@ -142,11 +151,7 @@ drive_button_new_from_mount (GMount *mount)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 drive_button_dispose (GObject *object)
-#else
-drive_button_destroy (GtkObject *object)
-#endif
 {
     DriveButton *self = DRIVE_BUTTON (object);
 
@@ -158,13 +163,8 @@ drive_button_destroy (GtkObject *object)
 
     drive_button_reset_popup (self);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     if (G_OBJECT_CLASS (drive_button_parent_class)->dispose)
 	(* G_OBJECT_CLASS (drive_button_parent_class)->dispose) (object);
-#else
-    if (GTK_OBJECT_CLASS (drive_button_parent_class)->destroy)
-	(* GTK_OBJECT_CLASS (drive_button_parent_class)->destroy) (object);
-#endif
 }
 
 #if 0
@@ -263,10 +263,10 @@ drive_button_key_press (GtkWidget      *widget,
     DriveButton *self = DRIVE_BUTTON (widget);
 
     switch (event->keyval) {
-    case GDK_KP_Space:
-    case GDK_space:
-    case GDK_KP_Enter:
-    case GDK_Return:
+    case GDK_KEY_KP_Space:
+    case GDK_KEY_space:
+    case GDK_KEY_KP_Enter:
+    case GDK_KEY_Return:
 	drive_button_ensure_popup (self);
 	if (self->popup_menu) {
 	    gtk_menu_popup (GTK_MENU (self->popup_menu), NULL, NULL,
@@ -379,8 +379,13 @@ drive_button_update (gpointer user_data)
     g_free (display_name);
 
     /* base the icon size on the desired button size */
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
+    gtk_widget_get_preferred_size (gtk_bin_get_child (GTK_BIN (self)), NULL, &image_req);
+#else
     gtk_widget_size_request (GTK_WIDGET (self), &button_req);
     gtk_widget_size_request (gtk_bin_get_child (GTK_BIN (self)), &image_req);
+#endif
     width = self->icon_size - (button_req.width - image_req.width);
     height = self->icon_size - (button_req.height - image_req.height);
 
@@ -392,7 +397,11 @@ drive_button_update (gpointer user_data)
     if (icon_info)
     {
 	pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+#if GTK_CHECK_VERSION (3, 0, 0)
+	g_object_unref (icon_info);
+#else
 	gtk_icon_info_free (icon_info);
+#endif
     }
 
     g_object_unref (icon);
@@ -409,7 +418,11 @@ drive_button_update (gpointer user_data)
     gtk_image_set_from_pixbuf (GTK_IMAGE (gtk_bin_get_child (GTK_BIN (self))), pixbuf);
     g_object_unref (pixbuf);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+    gtk_widget_get_preferred_size (GTK_WIDGET (self), NULL, &button_req);
+#else
     gtk_widget_size_request (GTK_WIDGET (self), &button_req);
+#endif
 
     return FALSE;
 }
@@ -476,11 +489,7 @@ static void
 drive_button_reset_popup (DriveButton *self)
 {
     if (self->popup_menu)
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_destroy (GTK_WIDGET (self->popup_menu));
-#else
-	gtk_object_destroy (GTK_OBJECT (self->popup_menu));
-#endif
     self->popup_menu = NULL;
 }
 
@@ -545,7 +554,7 @@ open_drive (DriveButton *self, GtkWidget *item)
     GFile *file = NULL;
     GList *files = NULL;
     GdkAppLaunchContext *launch_context;
-    GDesktopAppInfo *app_info;
+    GAppInfo *app_info;
 #else
     char *argv[3] = { "caja", NULL, NULL };
 
@@ -584,14 +593,21 @@ open_drive (DriveButton *self, GtkWidget *item)
 	g_return_if_reached();
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-    app_info = g_desktop_app_info_new ("caja.desktop");
+    app_info = g_app_info_get_default_for_type("inode/directory", FALSE);
+    if (!app_info)
+      app_info = G_APP_INFO (g_desktop_app_info_new ("caja.desktop"));
 
     if (app_info) {
+#if GTK_CHECK_VERSION (3, 0, 0)
+	GdkDisplay *display = gtk_widget_get_display (item);
+	launch_context = gdk_display_get_app_launch_context (display);
+#else
 	launch_context = gdk_app_launch_context_new ();
+#endif
 	screen = gtk_widget_get_screen (GTK_WIDGET (self));
 	gdk_app_launch_context_set_screen (launch_context, screen);
 	files = g_list_prepend (files, file);
-	g_app_info_launch (G_APP_INFO (app_info),
+	g_app_info_launch (app_info,
 	files,
 	G_APP_LAUNCH_CONTEXT (launch_context),
 	&error);
@@ -619,13 +635,9 @@ open_drive (DriveButton *self, GtkWidget *item)
 	if (error)
 	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message, NULL);
 	else
-	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "Could not find Caja", NULL);
+	    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), "Could not find Caja");
 	g_signal_connect (dialog, "response",
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  G_CALLBACK (gtk_widget_destroy), NULL);
-#else
-			  G_CALLBACK (gtk_object_destroy), NULL);
-#endif
 	gtk_widget_show (dialog);
 	g_error_free (error);
     }
@@ -823,18 +835,23 @@ run_command (DriveButton *self, const char *command)
 	g_free (device_path);
 }
 
+static void dummy_async_ready_callback(GObject *source_object, GAsyncResult *res, gpointer user_data) {
+	/* do nothing */
+}
+
 static void
 mount_drive (DriveButton *self, GtkWidget *item)
 {
     if (self->volume) {
         GMountOperation *mount_op = gtk_mount_operation_new (NULL);
 	g_volume_mount (self->volume, G_MOUNT_MOUNT_NONE,
-			mount_op, NULL, NULL, NULL);
+			mount_op, NULL, dummy_async_ready_callback, NULL);
         g_object_unref (mount_op);
     } else {
 	g_return_if_reached();
     }
 }
+
 static void
 unmount_drive (DriveButton *self, GtkWidget *item)
 {
@@ -845,12 +862,12 @@ unmount_drive (DriveButton *self, GtkWidget *item)
 	if (mount)
 	{
 	    g_mount_unmount_with_operation (mount, G_MOUNT_UNMOUNT_NONE,
-	                                    NULL, NULL, NULL, NULL);
+	                                    NULL, NULL, dummy_async_ready_callback, NULL);
 	    g_object_unref (mount);
 	}
     } else if (self->mount) {
 	g_mount_unmount_with_operation (self->mount, G_MOUNT_UNMOUNT_NONE,
-			                NULL, NULL, NULL, NULL);
+			                NULL, NULL, dummy_async_ready_callback, NULL);
     } else {
 	g_return_if_reached();
     }
@@ -952,13 +969,11 @@ drive_button_ensure_popup (DriveButton *self)
     gtk_container_add (GTK_CONTAINER (self->popup_menu), item);
 
     if (mounted) {
-	if (!ejectable) {
-	    label = g_strdup_printf (_("Un_mount %s"), display_name);
-	    item = create_menu_item (self, NULL, label,
-				     G_CALLBACK (unmount_drive), TRUE);
-	    g_free (label);
-	    gtk_container_add (GTK_CONTAINER (self->popup_menu), item);
-	}
+        label = g_strdup_printf (_("Un_mount %s"), display_name);
+        item = create_menu_item (self, NULL, label,
+				 G_CALLBACK (unmount_drive), TRUE);
+        g_free (label);
+        gtk_container_add (GTK_CONTAINER (self->popup_menu), item);
     } else {
 	label = g_strdup_printf (_("_Mount %s"), display_name);
 	item = create_menu_item (self, NULL, label,
