@@ -20,12 +20,18 @@
 #include <config.h>
 #include <math.h>
 #include <stdlib.h>
+#include <libmate-desktop/mate-aboutdialog.h>
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
 #include "geyes.h"
 
 #define UPDATE_TIMEOUT 100
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 static void
 applet_back_change (MatePanelApplet			*a,
 		    MatePanelAppletBackgroundType	type,
@@ -99,8 +105,8 @@ calculate_pupil_xy (EyesApplet *eyes_applet,
 	 ny = y - MAX(height- eyes_applet->eye_height, 0) * yalign - eyes_applet->eye_height / 2;
   
 	 h = hypot (nx, ny);
-        if (h < 0.5 || abs (h) 
-            < (abs (hypot (eyes_applet->eye_height / 2, eyes_applet->eye_width / 2)) - eyes_applet->wall_thickness - eyes_applet->pupil_height)) {
+        if (h < 0.5 || fabs (h)
+            < (fabs (hypot (eyes_applet->eye_height / 2, eyes_applet->eye_width / 2)) - eyes_applet->wall_thickness - eyes_applet->pupil_height)) {
                 *pupil_x = nx + eyes_applet->eye_width / 2;
                 *pupil_y = ny + eyes_applet->eye_height / 2;
                 return;
@@ -154,14 +160,28 @@ draw_eye (EyesApplet *eyes_applet,
 static gint 
 timer_cb (EyesApplet *eyes_applet)
 {
+#if GTK_CHECK_VERSION (3, 0, 0)
+        GdkDisplay *display;
+        GdkDeviceManager *device_manager;
+        GdkDevice *device;
+#endif
         gint x, y;
         gint pupil_x, pupil_y;
         gint i;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+        display = gtk_widget_get_display (GTK_WIDGET (eyes_applet->applet));
+        device_manager = gdk_display_get_device_manager (display);
+        device = gdk_device_manager_get_client_pointer (device_manager);
+#endif
+
         for (i = 0; i < eyes_applet->num_eyes; i++) {
 		if (gtk_widget_get_realized (eyes_applet->eyes[i])) {
-			gtk_widget_get_pointer (eyes_applet->eyes[i], 
-						&x, &y);
+#if GTK_CHECK_VERSION (3, 0, 0)
+			gdk_window_get_device_position (gtk_widget_get_window (eyes_applet->eyes[i]), device, &x, &y, NULL);
+#else
+			gtk_widget_get_pointer (eyes_applet->eyes[i], &x, &y);
+#endif
 			if ((x != eyes_applet->pointer_last_x[i]) || (y != eyes_applet->pointer_last_y[i])) { 
 
 				calculate_pupil_xy (eyes_applet, x, y, &pupil_x, &pupil_y, eyes_applet->eyes[i]);
@@ -191,7 +211,7 @@ about_cb (GtkAction   *action,
 		NULL
 	};
 
-	gtk_show_about_dialog (NULL,
+	mate_show_about_dialog (NULL,
 		"version",	VERSION,
 		"comments",	_("A goofy set of eyes for the MATE "
 				  "panel. They follow your mouse."),
@@ -303,11 +323,7 @@ create_eyes (MatePanelApplet *applet)
 }
 
 static void
-#if GTK_CHECK_VERSION (3, 0, 0)
 dispose_cb (GObject *object, EyesApplet *eyes_applet)
-#else
-destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
-#endif
 {
 	g_return_if_fail (eyes_applet);
 
@@ -410,11 +426,7 @@ geyes_applet_fill (MatePanelApplet *applet)
         eyes_applet = create_eyes (applet);
 
         eyes_applet->timeout_id = g_timeout_add (
-#if GTK_CHECK_VERSION (3, 0, 0)
 		UPDATE_TIMEOUT, (GSourceFunc) timer_cb, eyes_applet);
-#else
-		UPDATE_TIMEOUT, (GtkFunction) timer_cb, eyes_applet);
-#endif
 
 	action_group = gtk_action_group_new ("Geyes Applet Actions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
@@ -445,13 +457,8 @@ geyes_applet_fill (MatePanelApplet *applet)
 			  G_CALLBACK (applet_back_change),
 			  eyes_applet);
 	g_signal_connect (eyes_applet->vbox,
-#if GTK_CHECK_VERSION (3, 0, 0)
 			  "dispose",
 			  G_CALLBACK (dispose_cb),
-#else
-			  "destroy",
-			  G_CALLBACK (destroy_cb),
-#endif
 			  eyes_applet);
 
 	gtk_widget_show_all (GTK_WIDGET (eyes_applet->applet));
