@@ -37,6 +37,11 @@
 
 #define NEVER_SENSITIVE "never_sensitive"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 struct _MateWeatherPrefPrivate {
 	GtkWidget* basic_detailed_btn;
 	GtkWidget* basic_temp_combo;
@@ -751,7 +756,7 @@ static void help_cb(GtkDialog* dialog)
 {
 	GError* error = NULL;
 
-	gtk_show_uri(gtk_widget_get_screen(GTK_WIDGET(dialog)), "help:mateweather/mateweather-settings", gtk_get_current_event_time(), &error);
+	gtk_show_uri(gtk_widget_get_screen(GTK_WIDGET(dialog)), "help:mateweather/mateweather-prefs", gtk_get_current_event_time(), &error);
 
 	if (error)
 	{
@@ -789,11 +794,7 @@ static void mateweather_pref_create(MateWeatherPref* pref)
 	GtkWidget* pref_basic_update_alignment;
 	GtkWidget* pref_basic_update_lbl;
 	GtkWidget* pref_basic_update_hbox;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GObject* pref_basic_update_spin_adj;
-#else
-	GtkObject* pref_basic_update_spin_adj;
-#endif
 	GtkWidget* pref_basic_update_sec_lbl;
 	GtkWidget* pref_basic_note_lbl;
 	GtkWidget* pref_loc_hbox;
