@@ -47,35 +47,29 @@ static void response_cb (GtkWidget *dialog, gint id, gpointer data);
 
 /* Based on a function found in wnck */
 static void
-set_icon_geometry  (GdkWindow *window,
-                  int        x,
-                  int        y,
-                  int        width,
-                  int        height)
+set_icon_geometry (GdkWindow *window,
+                   int        x,
+                   int        y,
+                   int        width,
+                   int        height)
 {
-      gulong data[4];
-#if GTK_CHECK_VERSION (3, 0, 0)
-      Display *dpy = gdk_x11_display_get_xdisplay (gdk_window_get_display (window));
-#else
-      Display *dpy = gdk_x11_drawable_get_xdisplay (window);
-#endif
+	gulong data[4];
+	Display *dpy;
 
-      data[0] = x;
-      data[1] = y;
-      data[2] = width;
-      data[3] = height;
+	dpy = gdk_x11_display_get_xdisplay (gdk_window_get_display (window));
 
-      XChangeProperty (dpy,
-                       GDK_WINDOW_XID (window),
-                       gdk_x11_get_xatom_by_name_for_display (
-#if GTK_CHECK_VERSION (3, 0, 0)
-			       gdk_window_get_display (window),
-#else
-			       gdk_drawable_get_display (window),
-#endif
-			       "_NET_WM_ICON_GEOMETRY"),
-		       XA_CARDINAL, 32, PropModeReplace,
-                       (guchar *)&data, 4);
+	data[0] = x;
+	data[1] = y;
+	data[2] = width;
+	data[3] = height;
+
+	XChangeProperty (dpy,
+	                 GDK_WINDOW_XID (window),
+	                 gdk_x11_get_xatom_by_name_for_display (
+	                     gdk_window_get_display (window),
+	                     "_NET_WM_ICON_GEOMETRY"),
+	                 XA_CARDINAL, 32, PropModeReplace,
+	                 (guchar *)&data, 4);
 }
 
 /* Called when a timeout occurs.  */
@@ -105,7 +99,7 @@ buffer_changed (GtkTextBuffer *buffer, StickyNote *note)
 
 /* Create a new (empty) Sticky Note at a specific position
    and with specific size */
-StickyNote *
+static StickyNote *
 stickynote_new_aux (GdkScreen *screen, gint x, gint y, gint w, gint h)
 {
 	StickyNote *note;
@@ -332,8 +326,6 @@ void stickynote_free(StickyNote *note)
 /* Change the sticky note title and color */
 void stickynote_change_properties (StickyNote *note)
 {
-	GdkColor color;
-	GdkColor font_color;
 	char *color_str = NULL;
 
 	gtk_entry_set_text(GTK_ENTRY(note->w_entry),
@@ -351,10 +343,16 @@ void stickynote_change_properties (StickyNote *note)
 
 	if (color_str)
 	{
+#if GTK_CHECK_VERSION (3, 0, 0)
+		GdkRGBA color;
+		gdk_rgba_parse (&color, color_str);
+		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_color), &color);
+#else
+		GdkColor color;
 		gdk_color_parse (color_str, &color);
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_color), &color);
+#endif
 		g_free (color_str);
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_color),
-				    &color);
 	}
 
 	if (note->font_color)
@@ -366,10 +364,16 @@ void stickynote_change_properties (StickyNote *note)
 
 	if (color_str)
 	{
+#if GTK_CHECK_VERSION (3, 0, 0)
+		GdkRGBA font_color;
+		gdk_rgba_parse (&font_color, color_str);
+		gtk_color_button_set_rgba (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
+#else
+		GdkColor font_color;
 		gdk_color_parse (color_str, &font_color);
+		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_font_color), &font_color);
+#endif
 		g_free (color_str);
-		gtk_color_button_set_color (GTK_COLOR_BUTTON (note->w_font_color),
-				    &font_color);
 	}
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(note->w_def_font),
@@ -388,7 +392,7 @@ response_cb (GtkWidget *dialog, gint id, gpointer data)
 {
         if (id == GTK_RESPONSE_HELP)
 		gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-				"help:mate-stickynotes_applet/stickynotes-settings-individual",
+				"help:mate-stickynotes-applet/stickynotes-settings-individual",
 				gtk_get_current_event_time (),
 				NULL);
         else if (id == GTK_RESPONSE_CLOSE)
@@ -434,6 +438,7 @@ stickynote_set_color (StickyNote  *note,
 		      gboolean     save)
 {
 	char *color_str_actual, *font_color_str_actual;
+	gboolean force_default, use_system_color;
 	GtkRcStyle *rc_style;
 
 	if (save) {
@@ -457,11 +462,14 @@ stickynote_set_color (StickyNote  *note,
 				note->color != NULL);
 	}
 
+	force_default = g_settings_get_boolean (stickynotes->settings, "force-default");
+	use_system_color = g_settings_get_boolean (stickynotes->settings, "use-system-color");
+
 	/* If "force_default" is enabled or color_str is NULL,
 	 * then we use the default color instead of color_str. */
-	if (!color_str || g_settings_get_boolean (stickynotes->settings, "force-default"))
+	if (!color_str || force_default)
 	{
-		if (g_settings_get_boolean (stickynotes->settings, "use-system-color"))
+		if (use_system_color)
 			color_str_actual = NULL;
 		else
 			color_str_actual = g_settings_get_string (stickynotes->settings, "default-color");
@@ -469,9 +477,9 @@ stickynote_set_color (StickyNote  *note,
 	else
 		color_str_actual = g_strdup (color_str);
 
-	if (!font_color_str || g_settings_get_boolean (stickynotes->settings, "force-default"))
+	if (!font_color_str || force_default)
 	{
-		if (g_settings_get_boolean (stickynotes->settings, "use-system-color"))
+		if (use_system_color)
 			font_color_str_actual = NULL;
 		else
 			font_color_str_actual = g_settings_get_string (stickynotes->settings, "default-font-color");
@@ -483,33 +491,39 @@ stickynote_set_color (StickyNote  *note,
 
 	/* Do not use custom colors if "use_system_color" is enabled */
 	if (color_str_actual) {
-		/* Custom colors */
-		GdkColor colors[6];
-		gboolean success[6];
-
-
+#if GTK_CHECK_VERSION (3, 0, 0)
+		GdkRGBA color;
+		gdk_rgba_parse (&color, color_str_actual);
+#endif
 		/* Make 4 shades of the color, getting darker from the
 		 * original, plus black and white */
+		GdkColor colors[6];
 		gint i;
 
 		for (i = 0; i <= 3; i++)
 		{
 			gdk_color_parse (color_str_actual, &colors[i]);
-
+#if GTK_CHECK_VERSION (3, 0, 0)
+			colors[i].red = (color.red * (10 - i)) / 10;
+			colors[i].green = (color.green * (10 - i)) / 10;
+			colors[i].blue = (color.blue * (10 - i)) / 10;
+#else
 			colors[i].red = (colors[i].red * (10 - i)) / 10;
 			colors[i].green = (colors[i].green * (10 - i)) / 10;
 			colors[i].blue = (colors[i].blue * (10 - i)) / 10;
+#endif
 		}
+
 		gdk_color_parse ("black", &colors[4]);
 		gdk_color_parse ("white", &colors[5]);
 
 #if !GTK_CHECK_VERSION (3, 0, 0)
-		/* Allocate these colors */
-		gdk_colormap_alloc_colors (gtk_widget_get_colormap (
-					note->w_window),
-				colors, 6, FALSE, TRUE, success);
-#endif
+		gboolean success[6];
 
+		/* Allocate these colors */
+		gdk_colormap_alloc_colors (gtk_widget_get_colormap (note->w_window),
+		                           colors, 6, FALSE, TRUE, success);
+#endif
 		/* Apply colors to style */
 		rc_style->base[GTK_STATE_NORMAL] = colors[0];
 		rc_style->bg[GTK_STATE_PRELIGHT] = colors[1];
@@ -521,7 +535,6 @@ stickynote_set_color (StickyNote  *note,
 			GTK_RC_BG | GTK_RC_BASE;
 		rc_style->color_flags[GTK_STATE_ACTIVE] = GTK_RC_BG;
 	}
-
 	else {
 		rc_style->color_flags[GTK_STATE_PRELIGHT] = 0;
 		rc_style->color_flags[GTK_STATE_NORMAL] = 0;
@@ -546,7 +559,16 @@ stickynote_set_color (StickyNote  *note,
 	{
 		GdkColor font_color;
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+		GdkRGBA color;
+
+		gdk_rgba_parse (&color, font_color_str_actual);
+		font_color.red = color.red;
+		font_color.green = color.green;
+		font_color.blue = color.blue;
+#else
 		gdk_color_parse (font_color_str_actual, &font_color);
+#endif
 
 		gtk_widget_modify_text (note->w_window,
 				GTK_STATE_NORMAL, &font_color);
@@ -555,7 +577,7 @@ stickynote_set_color (StickyNote  *note,
 		gtk_widget_modify_text (note->w_body,
 				GTK_STATE_NORMAL, &font_color);
 		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_NORMAL, &font_color);
+				GTK_STATE_PRELIGHT, &font_color);
 	}
 	else
 	{
@@ -566,7 +588,7 @@ stickynote_set_color (StickyNote  *note,
 		gtk_widget_modify_text (note->w_body,
 				GTK_STATE_NORMAL, NULL);
 		gtk_widget_modify_text (note->w_body,
-				GTK_STATE_NORMAL, NULL);
+				GTK_STATE_PRELIGHT, NULL);
 	}
 
 	if (color_str_actual)
@@ -838,11 +860,7 @@ stickynotes_save_now (void)
 
 	/* The XML file is $HOME/.config/mate/stickynotes-applet, most probably */
 	{
-		#if GLIB_CHECK_VERSION(2, 6, 0)
 			gchar* file = g_build_filename(g_get_user_config_dir(), "mate", "stickynotes-applet.xml", NULL);
-		#else // glib version < 2.6.0
-			gchar* file = g_build_filename(g_get_home_dir(), ".config", "mate", "stickynotes-applet.xml", NULL);
-		#endif
 
 		xmlSaveFormatFile(file, doc, 1);
 
@@ -859,11 +877,11 @@ stickynotes_save_now (void)
 void
 stickynotes_save (void)
 {
-  /* If a save isn't already schedules, save everything a minute from now. */
-  if (!save_scheduled) {
-    g_timeout_add_seconds (60, (GSourceFunc) stickynotes_save_now, NULL);
-    save_scheduled = TRUE;
-  }
+	/* If a save isn't already scheduled, save everything a minute from now. */
+	if (!save_scheduled) {
+		g_timeout_add_seconds (60, (GSourceFunc) stickynotes_save_now, NULL);
+		save_scheduled = TRUE;
+	}
 }
 
 /* Load all sticky notes from an XML configuration file */
@@ -877,14 +895,10 @@ stickynotes_load (GdkScreen *screen)
 	GList *new_notes, *tmp1;  /* Lists of StickyNote*'s */
 	GList *new_nodes; /* Lists of xmlNodePtr's */
 	int x, y, w, h;
+
 	/* The XML file is $HOME/.config/mate/stickynotes-applet, most probably */
 	{
-		/* retro-compatibilidad con ~/.mate2/ */
-		#if GLIB_CHECK_VERSION(2, 6, 0)
-			gchar* file = g_build_filename(g_get_user_config_dir(), "mate", "stickynotes-applet.xml", NULL);
-		#else // glib version < 2.6.0
-			gchar* file = g_build_filename(g_get_home_dir(), ".config", "mate", "stickynotes-applet.xml", NULL);
-		#endif
+		gchar* file = g_build_filename(g_get_user_config_dir(), "mate", "stickynotes-applet.xml", NULL);
 
 		if (g_file_test(file, G_FILE_TEST_EXISTS))
 		{
@@ -1007,11 +1021,11 @@ stickynotes_load (GdkScreen *screen)
 
 			/* Retrieve and set the font of the note */
 			{
-				gchar *font_str = (gchar *)xmlGetProp(node, XML_CHAR ("font"));
+				gchar *font_str = (gchar *)xmlGetProp (node, XML_CHAR ("font"));
 				if (font_str)
 					stickynote_set_font (note, font_str,
 							TRUE);
-				g_free(font_str);
+				g_free (font_str);
 			}
 
 			/* Retrieve the workspace */
