@@ -29,6 +29,7 @@
 #include <gtk/gtk.h>
 
 #include <libnotify/notify.h>
+#include <libmate-desktop/mate-aboutdialog.h>
 
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
@@ -44,6 +45,10 @@
 #define SHOW_NOTIFICATION_KEY   "show-notification"
 #define SHOW_DIALOG_KEY         "show-dialog"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#endif
+
 typedef struct
 {
     MatePanelApplet   *applet;
@@ -114,12 +119,13 @@ timer_callback (TimerApplet *applet)
     gint hours, minutes, seconds, duration, remaining;
 
     label = NULL;
-    name = NULL;
     tooltip = NULL;
 
+    name = g_settings_get_string (applet->settings, NAME_KEY);
+
     if (!applet->active)
     {
-        gtk_label_set_text (applet->label, "");
+        gtk_label_set_text (applet->label, name);
         gtk_widget_set_tooltip_text (GTK_WIDGET (applet->label), "");
         gtk_widget_hide (GTK_WIDGET (applet->pause_image));
     }
@@ -129,7 +135,6 @@ timer_callback (TimerApplet *applet)
             applet->elapsed += STEP;
 
         duration = g_settings_get_int (applet->settings, DURATION_KEY);
-        name = g_settings_get_string (applet->settings, NAME_KEY);
 
         remaining = duration - (applet->elapsed / 1000);
 
@@ -189,7 +194,6 @@ timer_callback (TimerApplet *applet)
         }
 
         g_free (label);
-        g_free (name);
         g_free (tooltip);
     }
 
@@ -199,6 +203,8 @@ timer_callback (TimerApplet *applet)
     gtk_action_set_sensitive (gtk_action_group_get_action (applet->action_group, "Stop"), applet->active);
     gtk_action_set_sensitive (gtk_action_group_get_action (applet->action_group, "Preferences"), !applet->active && !applet->pause);
 
+    g_free (name);
+
     return retval;
 }
 
@@ -246,7 +252,7 @@ timer_about_callback (GtkAction *action, TimerApplet *applet)
 {
     const char* authors[] = { "Stefano Karapetsas <stefano@karapetsas.com>", NULL };
 
-    gtk_show_about_dialog(NULL,
+    mate_show_about_dialog(NULL,
                           "version", VERSION,
                           "copyright", "Copyright © 2014 Stefano Karapetsas",
                           "authors", authors,
@@ -294,6 +300,7 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
     gtk_table_set_col_spacings (table, 12);
 
     gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 150);
+    gtk_container_set_border_width (GTK_CONTAINER (dialog), 10);
 
     widget = gtk_label_new (_("Name:"));
     gtk_misc_set_alignment (GTK_MISC (widget), 1.0, 0.5);
@@ -368,6 +375,12 @@ timer_preferences_callback (GtkAction *action, TimerApplet *applet)
     gtk_widget_show_all (GTK_WIDGET (dialog));
 }
 
+static void
+timer_settings_changed (GSettings *settings, gchar *key, TimerApplet *applet)
+{
+    timer_callback (applet);
+}
+
 static gboolean
 timer_applet_fill (MatePanelApplet* applet_widget)
 {
@@ -425,6 +438,10 @@ timer_applet_fill (MatePanelApplet* applet_widget)
     /* execute callback to set actions sensitiveness */
     timer_callback (applet);
 
+    /* GSettings callback */
+    g_signal_connect (G_OBJECT (applet->settings), "changed",
+                      G_CALLBACK (timer_settings_changed), applet);
+
     return TRUE;
 }
 
